abacusai.api_class.monitor — AbacusAI documentation

# `abacusai.api_class.monitor`

## Module Contents

### Classes

`ForecastingMonitorConfig` | Helper class that provides a standard way to create an ABC using
`StdDevThreshold` | Std Dev Threshold types
`ItemAttributesStdDevThreshold` | Item Attributes Std Dev Threshold for Monitor Alerts

class abacusai.api_class.monitor.ForecastingMonitorConfig

  Bases: `abacusai.api_class.abstract.ApiClass`

  Helper class that provides a standard way to create an ABC using inheritance.

  id_column: str
  timestamp_column: str
  target_column: str
  start_time: str
  end_time: str
  to_dict()

    Standardizes converting an ApiClass to dictionary. Keys of response dictionary are converted to camel case. This also validates the fields ( type, value, etc ) received in the dictionary.

class abacusai.api_class.monitor.StdDevThreshold

  Bases: `abacusai.api_class.abstract.ApiClass`

  Std Dev Threshold types

  Parameters:

    - threshold_type (StdDevThresholdType) – Type of threshold to apply to the item attributes.

    - value (float) – Value to use for the threshold.

  threshold_type: abacusai.api_class.enums.StdDevThresholdType
  value: float
  to_dict()

    Standardizes converting an ApiClass to dictionary. Keys of response dictionary are converted to camel case. This also validates the fields ( type, value, etc ) received in the dictionary.

class abacusai.api_class.monitor.ItemAttributesStdDevThreshold

  Bases: `abacusai.api_class.abstract.ApiClass`

  Item Attributes Std Dev Threshold for Monitor Alerts

  Parameters:

    - lower_bound (StdDevThreshold) – Lower bound for the item attributes.

    - upper_bound (StdDevThreshold) – Upper bound for the item attributes.

  lower_bound: StdDevThreshold
  upper_bound: StdDevThreshold
  to_dict()

    Standardizes converting an ApiClass to dictionary. Keys of response dictionary are converted to camel case. This also validates the fields ( type, value, etc ) received in the dictionary.